@@ -417,7 +417,8 @@ impl Env {
 
     Ok(JsArrayBufferValue::new(
       unsafe { JsArrayBuffer::from_raw_unchecked(self.0, raw_value) },
-      mem::ManuallyDrop::new(data),
+      data_ptr as *mut c_void,
+      length,
     ))
   }
 
@@ -437,13 +438,15 @@ impl Env {
       )
     })?;
 
+    mem::forget(data);
     Ok(JsArrayBufferValue::new(
       JsArrayBuffer(Value {
         env: self.0,
         value: raw_value,
         value_type: ValueType::Object,
       }),
-      mem::ManuallyDrop::new(data),
+      data_ptr as *mut c_void,
+      length,
     ))
   }
 
@@ -486,7 +489,8 @@ impl Env {
         value: raw_value,
         value_type: ValueType::Object,
       }),
-      mem::ManuallyDrop::new(Vec::from_raw_parts(data as *mut u8, length, length)),
+      data as *mut c_void,
+      length,
     ))
   }
 
@@ -520,7 +524,7 @@ impl Env {
   pub fn create_function_from_closure<R, F>(&self, name: &str, callback: F) -> Result<JsFunction>
   where
     F: 'static + Send + Sync + Fn(crate::CallContext<'_>) -> Result<R>,
-    R: NapiValue,
+    R: NapiRaw,
   {
     use crate::CallContext;
     let boxed_callback = Box::new(callback);
@@ -535,7 +539,7 @@ impl Env {
         name.as_ptr(),
         len,
         Some({
-          unsafe extern "C" fn trampoline<R: NapiValue, F: Fn(CallContext<'_>) -> Result<R>>(
+          unsafe extern "C" fn trampoline<R: NapiRaw, F: Fn(CallContext<'_>) -> Result<R>>(
             raw_env: sys::napi_env,
             cb_info: sys::napi_callback_info,
           ) -> sys::napi_value {
@@ -862,7 +866,7 @@ impl Env {
   /// This API create a new reference with the specified reference count to the Object passed in.
   pub fn create_reference<T>(&self, value: T) -> Result<Ref<()>>
   where
-    T: NapiValue,
+    T: NapiRaw,
   {
     let mut raw_ref = ptr::null_mut();
     let initial_ref_count = 1;
@@ -1066,7 +1070,7 @@ impl Env {
   #[inline]
   pub fn create_threadsafe_function<
     T: Send,
-    V: NapiValue,
+    V: NapiRaw,
     R: 'static + Send + FnMut(ThreadSafeCallContext<T>) -> Result<Vec<V>>,
   >(
     &self,
@@ -1292,7 +1296,7 @@ impl Env {
   pub fn from_js_value<T, V>(&self, value: V) -> Result<T>
   where
     T: DeserializeOwned + ?Sized,
-    V: NapiValue,
+    V: NapiRaw,
   {
     let value = Value {
       env: self.0,
@@ -1305,7 +1309,7 @@ impl Env {
 
   #[inline]
   /// This API represents the invocation of the Strict Equality algorithm as defined in [Section 7.2.14](https://tc39.es/ecma262/#sec-strict-equality-comparison) of the ECMAScript Language Specification.
-  pub fn strict_equals<A: NapiValue, B: NapiValue>(&self, a: A, b: B) -> Result<bool> {
+  pub fn strict_equals<A: NapiRaw, B: NapiRaw>(&self, a: A, b: B) -> Result<bool> {
     let mut result = false;
     check_status!(unsafe { sys::napi_strict_equals(self.0, a.raw(), b.raw(), &mut result) })?;
     Ok(result)
